@@ -4,13 +4,13 @@ use warnings;
 use 5.010; # state
 
 # ABSTRACT: Fully UTF-8 aware File::Find
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
+#pod =head1 SYNOPSIS
+#pod
 #pod =for test_synopsis
 #pod my @directories_to_search;
 #pod
-#pod =head1 SYNOPSIS
-#pod
 #pod     # Use the utf-8 versions of find and finddepth
 #pod     use File::Find::utf8;
 #pod     find(\&wanted, @directories_to_search);
@@ -247,26 +247,10 @@ File::Find::utf8 - Fully UTF-8 aware File::Find
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-    # Use the utf-8 versions of find and finddepth
-    use File::Find::utf8;
-    find(\&wanted, @directories_to_search);
-
-    # Revert back to non-utf-8 versions
-    no File::Find::utf8;
-    finddepth(\&wanted, @directories_to_search);
-
-    # Export only the find function
-    use File::Find::utf8 qw(find);
-    find(\&wanted, @directories_to_search);
-
-    # Export no functions
-    use File::Find::utf8 qw(:none); # NOT "use File::Find::utf8 qw();"!
-    File::Find::find(\&wanted, @directories_to_search);
-
 =head1 DESCRIPTION
 
 While the original L<File::Find> functions are capable of handling
@@ -323,10 +307,26 @@ I<always> enforced.
 
 =for test_synopsis my @directories_to_search;
 
+    # Use the utf-8 versions of find and finddepth
+    use File::Find::utf8;
+    find(\&wanted, @directories_to_search);
+
+    # Revert back to non-utf-8 versions
+    no File::Find::utf8;
+    finddepth(\&wanted, @directories_to_search);
+
+    # Export only the find function
+    use File::Find::utf8 qw(find);
+    find(\&wanted, @directories_to_search);
+
+    # Export no functions
+    use File::Find::utf8 qw(:none); # NOT "use File::Find::utf8 qw();"!
+    File::Find::find(\&wanted, @directories_to_search);
+
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-https://github.com/HayoBaan/File-Find-utf8/issues
+Please report any bugs or feature requests on the bugtracker
+L<website|https://github.com/HayoBaan/File-Find-utf8/issues>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -358,7 +358,7 @@ L<utf8::all> -- Turn on utf-8, all of it. This was also the module I first added
 
 =head1 AUTHOR
 
-Hayo Baan <info@hayobaan.nl>
+Hayo Baan <hayobaan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
